==> extclassgenerator-1.0.3-sources.jar: ch/rasc/extclassgenerator/ModelCacheKey.java <==
/**
 * Copyright 2013-2014 Ralph Schaer <ralphschaer@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ch.rasc.extclassgenerator;

final class ModelCacheKey {
	private final String className;

	private final IncludeValidation includeValidation;

	public ModelCacheKey(String className, IncludeValidation includeValidation) {
		this.className = className;
		this.includeValidation = includeValidation;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ (className == null ? 0 : className.hashCode());
		result = prime
				* result
				+ (includeValidation == null ? 0 : includeValidation.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		ModelCacheKey other = (ModelCacheKey) obj;
		if (className == null) {
			if (other.className != null) {
				return false;
			}
		}
		else if (!className.equals(other.className)) {
			return false;
		}
		if (includeValidation != other.includeValidation) {
			return false;
		}
		return true;
	}

}

==> extclassgenerator-1.0.4-sources.jar: ch/rasc/extclassgenerator/ModelCacheKey.java <==
/**
 * Copyright 2013-2014 Ralph Schaer <ralphschaer@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ch.rasc.extclassgenerator;

final class ModelCacheKey {
	private final String className;

	private final IncludeValidation includeValidation;

	public ModelCacheKey(String className, IncludeValidation includeValidation) {
		this.className = className;
		this.includeValidation = includeValidation;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + (className == null ? 0 : className.hashCode());
		result = prime * result
				+ (includeValidation == null ? 0 : includeValidation.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		ModelCacheKey other = (ModelCacheKey) obj;
		if (className == null) {
			if (other.className != null) {
				return false;
			}
		}
		else if (!className.equals(other.className)) {
			return false;
		}
		if (includeValidation != other.includeValidation) {
			return false;
		}
		return true;
	}

}
